FINANCIAL ADVISOR INSIGHTS: December 29 - Business Insider
Author: Elena Holodny
Description: "Russia is a reminder that emerging markets remain subject to swift and meaningful changes in capital flows."
Date: 2014-12-29

- Featured
- Trending
- Recent

###

From
To
You have successfully emailed the post.
Wealth Advisor More: Financial Advisor Insights

# What's Happening In Russia Is A Big Wake-Up Call For Emerging Market Investors

- Elena Holodny

- Dec. 29, 2014, 5:39 PM
- 2,127
- 1

- facebook
- linkedin
- twitter
- google+
- print
- email

- print
- email

- share
- share
- tweet
- share
- print
- email

- Share on Facebook
- Share on Twitter
- Share on Linkedin
- share
- print
- email

Wikimedia Commons

FA Insights is a daily newsletter from Business Insider that delivers the top news and commentary forfinancial advisors.

Russia's Problems Are A Huge Warning Sign About Emerging Markets (Morningstar)

Russia's seen a volatile December: hiked interest rates, increased inflation, and a plunging ruble. Morningstar's Karin Anderson suggests that Russia's problems reflect the larger risks associated with emerging markets.

"Emerging markets' fundamentals can change fairly quickly with changes in political regimes, commodities pricing, or geopolitical risk. Second, currency fluctuations can have a quick and pronounced impact on investors' assessment of the risks and valuations of emerging-markets bonds," writes Anderson.

"Because of those risks, Russia is a reminder that emerging markets remain subject to swift and meaningful changes in capital flows," Anderson adds.

F-Squared Paid $35 Million In A Settlement (The Wall Street Journal)

"F-Squared Investments Inc., which builds investment portfolios out of exchange-traded funds, admitted it misled clients about its track record and agreed to pay $35 million in a settlement with regulators," reports Corrie Driebusch.

The SEC filed separate civil charges against the former CEO. He stepped down from his position last month, but his lawyers maintain that the SEC's allegations "are misdirected and meritless."

Analysts Aren't Feeling Great About Commodities In 2015 (Think Advisor)

Thanks in part to the strong US dollar, commodities have seen a tough year. And analysts don't think that things will get any better in the next one.

A recent Bloomberg survey sees Brent sliding to $50 a barrel, and Goldman Sachs analysts "see further declines in prices for oil and for other commodities with anticipated strengthening of the US dollar in 2015 and weaker demand for commodities in China," reports Janet Levaux.

Additionally, analysts have mixed feelings about agri-commodities in the next year.

An SEC Investor Advocate Will Push For Spending More On RIA Exams (Financial Advisor Magazine)

"Securities and Exchange Commission Investor Advocate Rick Fleming said Tuesday he will push SEC chairman Mary Jo White to use a 'significant' portion of its extra $150 million for 2015 to go to increase financial advisoroversight," reports Ted Knutson.

"Fraudulent or abusive practices by an investment advisor," said Fleming, "can be very difficult for an individual investor to detect, particularly if the advisor goes so far as to falsify account statements or other records."

Fleming reportedly has limited clout within the agency.

There Are 4 Things Advisors Need To Know To Avoid Getting Fired (Financial Planning)

Veteran Wall Streeter Charlotte Beyer has four tips for how to keep wealthy investors as clients.

The first two are related: advisors should probe and get feedback, and they should overcommunicate. The biggest reason advisors get fired, writes Beyer, is "it's always about communication — usually a lack of — every time."

Additionally, advisors should be diplomatic about demands by anticipating a client's needs. And finally, advisors should be consistent by emphasizing the long-term approach.

### Follow Financial Advisor Insights and never miss an update!

Get updates in your Facebook news feed.

Get updates in your inbox.

Privacy Policy

### Get updates in your inbox

Subscribe to Financial Advisor Insights and never miss an update!

Privacy Policy

- facebook
- linkedin
- twitter
- google+
- email

- email

- share
- share
- tweet
- share
- email

- Share on Facebook
- Share on Twitter
- Share on Linkedin
- Share on Google Plus
- email

### Recommended For You

- ####

- ####

- ####

- ####

- ####

### Comments

Loading

# What's Happening In Russia Is A Big Wake-Up Call For Emerging Market Investors

What's Happening In Russia Is A Big Wake-Up Call For Emerging Market Investors

FA Insights is a daily newsletter...

### Get Wealth Advisor Emails & Alerts

Learn More »

- Wealth Advisor Select

More
Featured

- Business Insider Select
- Tech Select
- Tech Chart Of The Day
- Markets Chart Of The Day
- 10 Things Before the Opening Bell
- Instant MBA
- Breaking News
- Business Insider Events

Entertainment

- Entertainment Select
- Sports Select

Finance

- Finance Select
- Markets Select
- Monday Scouting Report
- Your Money Select
- Financial Advisor Insights
- Smart Investor

Strategy

- Strategy Select
- Advertising Select
- Retail Select
- Careers Select
- Advertising: The Brief

Politics

- Politics Select
- Military Select
- Law & Order Select

Life

- Life Select
- Transportation Select
- Education Select

Tech

- Enterprise Select
- Science Select
- Mobile Chart Of The Day
- E-Commerce Chart Of The Day
- Payments Chart Of The Day
- Digital Media Chart Of The Day
- IoT Chart of the Day

Charts of the Day

- Sports Chart Of The Day

Top 10 Things

- 10 Things In Tech You Need To Know
- Closing Bell

##### Advertisement

### Your Money

NASDAQ Composite | 4,727 | -9.24 | (-0.195%)
S&P 500 | 2,058 | -0.7 | (-0.034%)
NYSE Composite | 10,831 | -8.32 | (-0.077%)

##### Sponsored By

### Featured

- Here's The Surprising Story Behind Spanx CEO Sara Blakely's 'Aha Moment'

  More "Idea Factory" »

- NBA POWER RANKINGS: Where Every Team Stands Going Into 2015

  More "2015 Watch List" »

- These 6 Charts Show How US Energy Boomed And Disrupted The Global Energy Game

  More "Think Global" »

- Peter Thiel Explains Why Mentorship Is Tricky For Tech Companies

  More "Idea Factory" »

### Welcome, !

##### You are logged into Facebook

##### Social:

- Your Activity|

  ### These articles have been shared on your timeline. You can remove them here:

- Options

  ### Notify me when a story is shared.

  Yes No

### Welcome, !

##### You are logged in with Google

##### Social:

- Your Activity|

  ### These articles have been added to your Google activity log. You can remove them here:

- Options

  ### Notify me when a story is shared.

  Yes No

### Trending

### BI Intelligence

Here's How The Internet Of Things Will Grow Across Home, Enterprise, And Government
Same-Day Delivery Services Are Going After Brick-And-Mortar Retailers’ Last Big Advantage
THE BEACONS FAQ: It's Time To Set The Story Straight
How Social Networks Are Driving More Sales And Influencing Online And Offline Purchases

### Read Business Insider On The Go

FREE App
Download

Available for iPhone, iPad, Android, BlackBerry and Windows

#####

### Find A Job

- Tech Jobs
- Media Jobs
- Finance Jobs

- C-Level Jobs
- Design Jobs
- Sales Jobs

### Thanks to our partners